@@ -23,6 +23,8 @@
 #include "poppler.h"
 #include "poppler-private.h"
 
+#include <new>
+
 /**
  * SECTION:poppler-attachment
  * @short_description: Attachments
@@ -32,15 +34,13 @@
 /* FIXME: We need to add gettext support sometime */
 #define _(x) (x)
 
-typedef struct _PopplerAttachmentPrivate PopplerAttachmentPrivate;
-struct _PopplerAttachmentPrivate
+struct PopplerAttachmentPrivate
 {
-  Object obj_stream;
+  Object obj_stream{};
 };
 
 #define POPPLER_ATTACHMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), POPPLER_TYPE_ATTACHMENT, PopplerAttachmentPrivate))
 
-static void poppler_attachment_dispose (GObject *obj);
 static void poppler_attachment_finalize (GObject *obj);
 
 G_DEFINE_TYPE (PopplerAttachment, poppler_attachment, G_TYPE_OBJECT)
@@ -48,27 +48,19 @@ G_DEFINE_TYPE (PopplerAttachment, poppler_attachment, G_TYPE_OBJECT)
 static void
 poppler_attachment_init (PopplerAttachment *attachment)
 {
+  void *place;
+
+  place = g_type_instance_get_private ((GTypeInstance*)attachment, POPPLER_TYPE_ATTACHMENT);
+  new (place) PopplerAttachmentPrivate();
 }
 
 static void
 poppler_attachment_class_init (PopplerAttachmentClass *klass)
 {
-  G_OBJECT_CLASS (klass)->dispose = poppler_attachment_dispose;
   G_OBJECT_CLASS (klass)->finalize = poppler_attachment_finalize;
   g_type_class_add_private (klass, sizeof (PopplerAttachmentPrivate));
 }
 
-static void
-poppler_attachment_dispose (GObject *obj)
-{
-  PopplerAttachmentPrivate *priv;
-
-  priv = POPPLER_ATTACHMENT_GET_PRIVATE (obj);
-  priv->obj_stream = Object();
-
-  G_OBJECT_CLASS (poppler_attachment_parent_class)->dispose (obj);
-}
-
 static void
 poppler_attachment_finalize (GObject *obj)
 {
@@ -87,7 +79,9 @@ poppler_attachment_finalize (GObject *obj)
   if (attachment->checksum)
     g_string_free (attachment->checksum, TRUE);
   attachment->checksum = nullptr;
-  
+
+  POPPLER_ATTACHMENT_GET_PRIVATE (obj)->~PopplerAttachmentPrivate ();
+
   G_OBJECT_CLASS (poppler_attachment_parent_class)->finalize (obj);
 }
 
@@ -111,7 +105,7 @@ _poppler_attachment_new (FileSpec *emb_file)
     attachment->description = _poppler_goo_string_to_utf8 (emb_file->getDescription ());
 
   embFile = emb_file->getEmbeddedFile();
-  if (embFile != NULL && embFile->streamObject()->isStream())
+  if (embFile != nullptr && embFile->streamObject()->isStream())
     {
       attachment->size = embFile->size ();
 
@@ -121,7 +115,7 @@ _poppler_attachment_new (FileSpec *emb_file)
         _poppler_convert_pdf_date_to_gtime (embFile->modDate (), (time_t *)&attachment->mtime);
 
       if (embFile->checksum () && embFile->checksum ()->getLength () > 0)
-        attachment->checksum = g_string_new_len (embFile->checksum ()->getCString (),
+        attachment->checksum = g_string_new_len (embFile->checksum ()->c_str (),
                                                  embFile->checksum ()->getLength ());
       priv->obj_stream = embFile->streamObject()->copy();
     }
