@@ -165,149 +165,316 @@ typedef enum /*< flags >*/
 
 } PopplerPermissions;
 
+/**
+ * PopplerPDFSubtype:
+ * @POPPLER_PDF_SUBTYPE_UNSET: Null
+ * @POPPLER_PDF_SUBTYPE_PDF_A: ISO 19005 - Document management -- Electronic document file format for long-term preservation (PDF/A)
+ * @POPPLER_PDF_SUBTYPE_PDF_E: ISO 24517 - Document management -- Engineering document format using PDF (PDF/E)
+ * @POPPLER_PDF_SUBTYPE_PDF_UA: ISO 14289 - Document management applications -- Electronic document file format enhancement for accessibility (PDF/UA)
+ * @POPPLER_PDF_SUBTYPE_PDF_VT: ISO 16612 - Graphic technology -- Variable data exchange (PDF/VT)
+ * @POPPLER_PDF_SUBTYPE_PDF_X: ISO 15930 - Graphic technology -- Prepress digital data exchange (PDF/X)
+ * @POPPLER_PDF_SUBTYPE_NONE: Not compliant with the above standards
+ *
+ * PDF Subtype
+ *
+ * Since: 0.70
+ */
+typedef enum
+{
+  POPPLER_PDF_SUBTYPE_UNSET,
+  POPPLER_PDF_SUBTYPE_PDF_A,
+  POPPLER_PDF_SUBTYPE_PDF_E,
+  POPPLER_PDF_SUBTYPE_PDF_UA,
+  POPPLER_PDF_SUBTYPE_PDF_VT,
+  POPPLER_PDF_SUBTYPE_PDF_X,
+  POPPLER_PDF_SUBTYPE_NONE
+} PopplerPDFSubtype;
 
+/**
+ * PopplerPDFPart:
+ * @POPPLER_PDF_SUBTYPE_PART_UNSET: Null
+ * @POPPLER_PDF_SUBTYPE_PART_1: 1
+ * @POPPLER_PDF_SUBTYPE_PART_2: 2
+ * @POPPLER_PDF_SUBTYPE_PART_3: 3
+ * @POPPLER_PDF_SUBTYPE_PART_4: 4
+ * @POPPLER_PDF_SUBTYPE_PART_5: 5
+ * @POPPLER_PDF_SUBTYPE_PART_6: 6
+ * @POPPLER_PDF_SUBTYPE_PART_7: 7
+ * @POPPLER_PDF_SUBTYPE_PART_8: 8
+ * @POPPLER_PDF_SUBTYPE_PART_NONE: No part available
+ *
+ * PDF Subtype Part
+ *
+ * Since: 0.70
+ */
+typedef enum
+{
+  POPPLER_PDF_SUBTYPE_PART_UNSET,
+  POPPLER_PDF_SUBTYPE_PART_1,
+  POPPLER_PDF_SUBTYPE_PART_2,
+  POPPLER_PDF_SUBTYPE_PART_3,
+  POPPLER_PDF_SUBTYPE_PART_4,
+  POPPLER_PDF_SUBTYPE_PART_5,
+  POPPLER_PDF_SUBTYPE_PART_6,
+  POPPLER_PDF_SUBTYPE_PART_7,
+  POPPLER_PDF_SUBTYPE_PART_8,
+  POPPLER_PDF_SUBTYPE_PART_NONE
+} PopplerPDFPart;
 
+/**
+ * PopplerPDFConformance:
+ * @POPPLER_PDF_SUBTYPE_CONF_UNSET: Null
+ * @POPPLER_PDF_SUBTYPE_CONF_A: Level A (accessible) conformance (PDF/A)
+ * @POPPLER_PDF_SUBTYPE_CONF_B: Level B (basic) conformance (PDF/A)
+ * @POPPLER_PDF_SUBTYPE_CONF_G: Level G (external graphical content) (PDF/X)
+ * @POPPLER_PDF_SUBTYPE_CONF_N: Level N (external ICC Profile) (PDF/X)
+ * @POPPLER_PDF_SUBTYPE_CONF_P: Level P (ICC Profile) (PDF/X)
+ * @POPPLER_PDF_SUBTYPE_CONF_PG: Level PG (conjuction of P and G) (PDF/X)
+ * @POPPLER_PDF_SUBTYPE_CONF_U: Level U (Unicode) conformance (PDF/A)
+ * @POPPLER_PDF_SUBTYPE_CONF_NONE: No conformance level available
+ *
+ * PDF Subtype Conformance
+ *
+ * Since: 0.70
+ */
+typedef enum
+{
+  POPPLER_PDF_SUBTYPE_CONF_UNSET,
+  POPPLER_PDF_SUBTYPE_CONF_A,
+  POPPLER_PDF_SUBTYPE_CONF_B,
+  POPPLER_PDF_SUBTYPE_CONF_G,
+  POPPLER_PDF_SUBTYPE_CONF_N,
+  POPPLER_PDF_SUBTYPE_CONF_P,
+  POPPLER_PDF_SUBTYPE_CONF_PG,
+  POPPLER_PDF_SUBTYPE_CONF_U,
+  POPPLER_PDF_SUBTYPE_CONF_NONE
+} PopplerPDFConformance;
+
+POPPLER_PUBLIC
 GType              poppler_document_get_type               (void) G_GNUC_CONST;
+POPPLER_PUBLIC
 PopplerDocument   *poppler_document_new_from_file          (const char      *uri,
 							    const char      *password,
 							    GError         **error);
+POPPLER_PUBLIC
 PopplerDocument   *poppler_document_new_from_data          (char            *data,
 							    int              length,
 							    const char      *password,
 							    GError         **error);
+POPPLER_PUBLIC
 PopplerDocument   *poppler_document_new_from_stream        (GInputStream    *stream,
                                                             goffset          length,
                                                             const char      *password,
                                                             GCancellable    *cancellable,
                                                             GError         **error);
+POPPLER_PUBLIC
 PopplerDocument   *poppler_document_new_from_gfile         (GFile           *file,
                                                             const char      *password,
                                                             GCancellable    *cancellable,
                                                             GError         **error);
+POPPLER_PUBLIC
 gboolean           poppler_document_save                   (PopplerDocument *document,
 							    const char      *uri,
 							    GError         **error);
+POPPLER_PUBLIC
 gboolean           poppler_document_save_a_copy            (PopplerDocument *document,
 							    const char      *uri,
 							    GError         **error);
+POPPLER_PUBLIC
 gboolean           poppler_document_get_id                 (PopplerDocument *document,
 							    gchar          **permanent_id,
 							    gchar          **update_id);
+POPPLER_PUBLIC
 int                poppler_document_get_n_pages            (PopplerDocument *document);
+POPPLER_PUBLIC
 PopplerPage       *poppler_document_get_page               (PopplerDocument *document,
 							    int              index);
+POPPLER_PUBLIC
 PopplerPage       *poppler_document_get_page_by_label      (PopplerDocument *document,
 							    const char      *label);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_pdf_version_string (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_get_pdf_version        (PopplerDocument *document,
 							    guint           *major_version,
 							    guint           *minor_version);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_title              (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_title              (PopplerDocument *document,
 							    const gchar     *title);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_author             (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_author             (PopplerDocument *document,
 							    const gchar     *author);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_subject            (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_subject            (PopplerDocument *document,
 							    const gchar     *subject);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_keywords           (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_keywords           (PopplerDocument *document,
                                                             const gchar     *keywords);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_creator            (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_creator            (PopplerDocument *document,
                                                             const gchar     *creator);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_producer           (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_producer           (PopplerDocument *document,
                                                             const gchar     *producer);
+POPPLER_PUBLIC
 time_t             poppler_document_get_creation_date      (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_creation_date      (PopplerDocument *document,
                                                             time_t           creation_date);
+POPPLER_PUBLIC
 time_t             poppler_document_get_modification_date  (PopplerDocument *document);
+POPPLER_PUBLIC
 void               poppler_document_set_modification_date  (PopplerDocument *document,
                                                             time_t           modification_date);
+POPPLER_PUBLIC
 gboolean           poppler_document_is_linearized          (PopplerDocument *document);
+POPPLER_PUBLIC
 PopplerPageLayout  poppler_document_get_page_layout        (PopplerDocument *document);
+POPPLER_PUBLIC
 PopplerPageMode    poppler_document_get_page_mode          (PopplerDocument *document);
+POPPLER_PUBLIC
 PopplerPermissions poppler_document_get_permissions        (PopplerDocument *document);
+POPPLER_PUBLIC
+gchar             *poppler_document_get_pdf_subtype_string (PopplerDocument *document);
+POPPLER_PUBLIC
+PopplerPDFSubtype  poppler_document_get_pdf_subtype        (PopplerDocument *document);
+POPPLER_PUBLIC
+PopplerPDFPart     poppler_document_get_pdf_part           (PopplerDocument *document);
+POPPLER_PUBLIC
+PopplerPDFConformance poppler_document_get_pdf_conformance (PopplerDocument *document);
+POPPLER_PUBLIC
 gchar             *poppler_document_get_metadata           (PopplerDocument *document);
 
 /* Attachments */
+POPPLER_PUBLIC
 guint              poppler_document_get_n_attachments      (PopplerDocument  *document);
+POPPLER_PUBLIC
 gboolean           poppler_document_has_attachments        (PopplerDocument  *document);
+POPPLER_PUBLIC
 GList             *poppler_document_get_attachments        (PopplerDocument  *document);
 
 /* Links */
+POPPLER_PUBLIC
 PopplerDest       *poppler_document_find_dest              (PopplerDocument  *document,
 							    const gchar      *link_name);
 
 /* Form */
+POPPLER_PUBLIC
 PopplerFormField  *poppler_document_get_form_field         (PopplerDocument  *document,
 							    gint              id);
 
 /* Interface for getting the Index of a poppler_document */
 #define POPPLER_TYPE_INDEX_ITER                 (poppler_index_iter_get_type ())
+POPPLER_PUBLIC
 GType             poppler_index_iter_get_type   (void) G_GNUC_CONST;
+POPPLER_PUBLIC
 PopplerIndexIter *poppler_index_iter_new        (PopplerDocument   *document);
+POPPLER_PUBLIC
 PopplerIndexIter *poppler_index_iter_copy       (PopplerIndexIter  *iter);
+POPPLER_PUBLIC
 void              poppler_index_iter_free       (PopplerIndexIter  *iter);
 
+POPPLER_PUBLIC
 PopplerIndexIter *poppler_index_iter_get_child  (PopplerIndexIter  *parent);
+POPPLER_PUBLIC
 gboolean	  poppler_index_iter_is_open    (PopplerIndexIter  *iter);
+POPPLER_PUBLIC
 PopplerAction    *poppler_index_iter_get_action (PopplerIndexIter  *iter);
+POPPLER_PUBLIC
 gboolean          poppler_index_iter_next       (PopplerIndexIter  *iter);
 
 /* Interface for getting the Fonts of a poppler_document */
 #define POPPLER_TYPE_FONT_INFO             (poppler_font_info_get_type ())
 #define POPPLER_FONT_INFO(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), POPPLER_TYPE_FONT_INFO, PopplerFontInfo))
 #define POPPLER_IS_FONT_INFO(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), POPPLER_TYPE_FONT_INFO))
+POPPLER_PUBLIC
 GType             poppler_font_info_get_type       (void) G_GNUC_CONST;
+POPPLER_PUBLIC
 PopplerFontInfo  *poppler_font_info_new            (PopplerDocument   *document);
+POPPLER_PUBLIC
 gboolean          poppler_font_info_scan           (PopplerFontInfo   *font_info,
 						    int                n_pages,
 						    PopplerFontsIter **iter);
+POPPLER_PUBLIC
 void             poppler_font_info_free            (PopplerFontInfo   *font_info);
 
 #define POPPLER_TYPE_FONTS_ITER                    (poppler_fonts_iter_get_type ())
+POPPLER_PUBLIC
 GType             poppler_fonts_iter_get_type      (void) G_GNUC_CONST;
+POPPLER_PUBLIC
 PopplerFontsIter *poppler_fonts_iter_copy          (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 void              poppler_fonts_iter_free          (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 const char       *poppler_fonts_iter_get_name      (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 const char       *poppler_fonts_iter_get_full_name (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 const char       *poppler_fonts_iter_get_substitute_name (PopplerFontsIter *iter);
+POPPLER_PUBLIC
 const char       *poppler_fonts_iter_get_file_name (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 PopplerFontType   poppler_fonts_iter_get_font_type (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 const char       *poppler_fonts_iter_get_encoding  (PopplerFontsIter *iter);
+POPPLER_PUBLIC
 gboolean	  poppler_fonts_iter_is_embedded   (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 gboolean	  poppler_fonts_iter_is_subset     (PopplerFontsIter  *iter);
+POPPLER_PUBLIC
 gboolean          poppler_fonts_iter_next          (PopplerFontsIter  *iter);
 
 /* Interface for getting the Layers of a poppler_document */
 #define POPPLER_TYPE_LAYERS_ITER                   (poppler_layers_iter_get_type ())
+POPPLER_PUBLIC
 GType              poppler_layers_iter_get_type    (void) G_GNUC_CONST;
+POPPLER_PUBLIC
 PopplerLayersIter *poppler_layers_iter_new         (PopplerDocument   *document);
+POPPLER_PUBLIC
 PopplerLayersIter *poppler_layers_iter_copy        (PopplerLayersIter *iter);
+POPPLER_PUBLIC
 void               poppler_layers_iter_free        (PopplerLayersIter *iter);
 
+POPPLER_PUBLIC
 PopplerLayersIter *poppler_layers_iter_get_child   (PopplerLayersIter *parent);
+POPPLER_PUBLIC
 gchar             *poppler_layers_iter_get_title   (PopplerLayersIter *iter);
+POPPLER_PUBLIC
 PopplerLayer      *poppler_layers_iter_get_layer   (PopplerLayersIter *iter);
+POPPLER_PUBLIC
 gboolean           poppler_layers_iter_next        (PopplerLayersIter *iter);
 
 /* Export to ps */
 #define POPPLER_TYPE_PS_FILE             (poppler_ps_file_get_type ())
 #define POPPLER_PS_FILE(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), POPPLER_TYPE_PS_FILE, PopplerPSFile))
 #define POPPLER_IS_PS_FILE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), POPPLER_TYPE_PS_FILE))
+POPPLER_PUBLIC
 GType          poppler_ps_file_get_type       (void) G_GNUC_CONST;
+POPPLER_PUBLIC
 PopplerPSFile *poppler_ps_file_new            (PopplerDocument *document,
                                                const char      *filename,
                                                int              first_page,
                                                int              n_pages);
+POPPLER_PUBLIC
 void           poppler_ps_file_set_paper_size (PopplerPSFile   *ps_file,
                                                double           width,
                                                double           height);
+POPPLER_PUBLIC
 void           poppler_ps_file_set_duplex     (PopplerPSFile   *ps_file,
                                                gboolean         duplex);
+POPPLER_PUBLIC
 void           poppler_ps_file_free           (PopplerPSFile   *ps_file);
 
 
