@@ -84,7 +84,7 @@ poppler_media_init (PopplerMedia *media)
 }
 
 PopplerMedia *
-_poppler_media_new (MediaRendition *poppler_media)
+_poppler_media_new (const MediaRendition *poppler_media)
 {
   PopplerMedia *media;
 
@@ -93,14 +93,14 @@ _poppler_media_new (MediaRendition *poppler_media)
   media = POPPLER_MEDIA (g_object_new (POPPLER_TYPE_MEDIA, nullptr));
 
   if (poppler_media->getIsEmbedded()) {
-    GooString* mime_type;
+    const GooString* mime_type;
 
     media->stream = poppler_media->getEmbbededStreamObject()->copy();
     mime_type = poppler_media->getContentType();
     if (mime_type)
-      media->mime_type = g_strdup (mime_type->getCString());
+      media->mime_type = g_strdup (mime_type->c_str());
   } else {
-    media->filename = g_strdup (poppler_media->getFileName()->getCString());
+    media->filename = g_strdup (poppler_media->getFileName()->c_str());
   }
 
   return media;
