@@ -417,7 +417,7 @@ CairoFreeTypeFont *CairoFreeTypeFont::create(GfxFont *gfxFont, XRef *xref,
 
   if (!(fontLoc = gfxFont->locateFont(xref, nullptr))) {
     error(errSyntaxError, -1, "Couldn't find a font for '{0:s}'",
-    	gfxFont->getName() ? gfxFont->getName()->getCString()
+    	gfxFont->getName() ? gfxFont->getName()->c_str()
 	                       : "(unnamed)");
     goto err2;
   }
@@ -436,7 +436,7 @@ CairoFreeTypeFont *CairoFreeTypeFont::create(GfxFont *gfxFont, XRef *xref,
   }
 
   if (fileName != nullptr) {
-    fileNameC = fileName->getCString();
+    fileNameC = fileName->c_str();
   }
 
   switch (fontType) {
