@@ -10,6 +10,7 @@
 // Copyright (C) 2012, 2017, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -28,7 +29,7 @@
 
 #include "FileSpec.h"
 
-EmbFile::EmbFile(const Object *efStream)
+EmbFile::EmbFile(Object &&efStream)
 {
   m_size = -1;
   m_createDate = nullptr;
@@ -36,11 +37,11 @@ EmbFile::EmbFile(const Object *efStream)
   m_checksum = nullptr;
   m_mimetype = nullptr;
 
-  m_objStr = efStream->copy();
+  m_objStr = std::move(efStream);
 
-  if (efStream->isStream()) {
+  if (m_objStr.isStream()) {
     // dataDict corresponds to Table 3.41 in the PDF1.6 spec.
-    Dict *dataDict = efStream->streamGetDict();
+    Dict *dataDict = m_objStr.streamGetDict();
 
     // subtype is normally the mimetype
     Object subtypeName = dataDict->lookup("Subtype");
@@ -93,6 +94,9 @@ bool EmbFile::save(const char *path) {
 bool EmbFile::save2(FILE *f) {
   int c;
 
+  if (unlikely(!m_objStr.isStream()))
+    return false;
+
   m_objStr.streamReset();
   while ((c = m_objStr.streamGetChar()) != EOF) {
     fputc(c, f);
@@ -152,10 +156,8 @@ EmbFile *FileSpec::getEmbeddedFile()
   if (embFile)
     return embFile;
 
-  Object obj1;
   XRef *xref = fileSpec.getDict()->getXRef();
-  obj1 = fileStream.fetch(xref);
-  embFile = new EmbFile(&obj1);
+  embFile = new EmbFile(fileStream.fetch(xref));
 
   return embFile;
 }
