@@ -13,7 +13,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2005, 2007-2010, 2012, 2015, 2017 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2005, 2007-2010, 2012, 2015, 2017, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2005 Jonathan Blandford <jrb@redhat.com>
 // Copyright (C) 2006 Takashi Iwai <tiwai@suse.de>
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
@@ -26,6 +26,7 @@
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2013 Jason Crain <jason@aquaticape.us>
+// Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -35,27 +36,21 @@
 #ifndef GLOBALPARAMS_H
 #define GLOBALPARAMS_H
 
-#ifdef USE_GCC_PRAGMAS
-#pragma interface
-#endif
-
 #include <assert.h>
 #include "poppler-config.h"
 #include <stdio.h>
 #include "goo/gtypes.h"
 #include "CharTypes.h"
-
-#ifdef MULTITHREADED
-#include "goo/GooMutex.h"
-#endif
+#include "UnicodeMap.h"
+#include <unordered_map>
+#include <string>
+#include <mutex>
 
 class GooString;
 class GooList;
-class GooHash;
 class NameToCharCode;
 class CharCodeToUnicode;
 class CharCodeToUnicodeCache;
-class UnicodeMap;
 class UnicodeMapCache;
 class CMap;
 class CMapCache;
@@ -104,10 +99,13 @@ class GlobalParams {
 public:
 
   // Initialize the global parameters
-  GlobalParams(const char *customPopplerDataDir = NULL);
+  GlobalParams(const char *customPopplerDataDir = nullptr);
 
   ~GlobalParams();
 
+  GlobalParams(const GlobalParams &) = delete;
+  GlobalParams& operator=(const GlobalParams &) = delete;
+
   void setupBaseFonts(char *dir);
 
   //----- accessors
@@ -122,68 +120,59 @@ public:
   // lookups or text extraction with ZapfDingbats fonts.
   Unicode mapNameToUnicodeAll(const char *charName);
 
-  UnicodeMap *getResidentUnicodeMap(GooString *encodingName);
-  FILE *getUnicodeMapFile(GooString *encodingName);
-  FILE *findCMapFile(GooString *collection, GooString *cMapName);
-  FILE *findToUnicodeFile(GooString *name);
-  GooString *findFontFile(GooString *fontName);
-  GooString *findBase14FontFile(GooString *base14Name, GfxFont *font);
+  UnicodeMap *getResidentUnicodeMap(const GooString *encodingName);
+  FILE *getUnicodeMapFile(const GooString *encodingName);
+  FILE *findCMapFile(const GooString *collection, const GooString *cMapName);
+  FILE *findToUnicodeFile(const GooString *name);
+  GooString *findFontFile(const GooString *fontName);
+  GooString *findBase14FontFile(const GooString *base14Name, GfxFont *font);
   GooString *findSystemFontFile(GfxFont *font, SysFontType *type,
-			      int *fontNum, GooString *substituteFontName = NULL, 
-		              GooString *base14Name = NULL);
-  GBool getPSExpandSmaller();
-  GBool getPSShrinkLarger();
+			      int *fontNum, GooString *substituteFontName = nullptr,
+		              const GooString *base14Name = nullptr);
+  bool getPSExpandSmaller();
+  bool getPSShrinkLarger();
   PSLevel getPSLevel();
   GooString *getTextEncodingName();
   EndOfLineKind getTextEOL();
-  GBool getTextPageBreaks();
-  GBool getEnableFreeType();
-  GBool getOverprintPreview() { return overprintPreview; }
-  GBool getPrintCommands();
-  GBool getProfileCommands();
-  GBool getErrQuiet();
+  bool getTextPageBreaks();
+  bool getEnableFreeType();
+  bool getOverprintPreview() { return overprintPreview; }
+  bool getPrintCommands();
+  bool getProfileCommands();
+  bool getErrQuiet();
 
   CharCodeToUnicode *getCIDToUnicode(GooString *collection);
-  CharCodeToUnicode *getUnicodeToUnicode(GooString *fontName);
   UnicodeMap *getUnicodeMap(GooString *encodingName);
-  CMap *getCMap(GooString *collection, GooString *cMapName, Stream *stream = NULL);
+  CMap *getCMap(const GooString *collection, GooString *cMapName, Stream *stream = nullptr);
   UnicodeMap *getTextEncoding();
-#ifdef ENABLE_PLUGINS
-  GBool loadPlugin(char *type, char *name);
-#endif
 
   GooList *getEncodingNames();
 
   //----- functions to set parameters
   void addFontFile(GooString *fontName, GooString *path);
-  void setPSExpandSmaller(GBool expand);
-  void setPSShrinkLarger(GBool shrink);
+  void setPSExpandSmaller(bool expand);
+  void setPSShrinkLarger(bool shrink);
   void setPSLevel(PSLevel level);
   void setTextEncoding(char *encodingName);
-  GBool setTextEOL(char *s);
-  void setTextPageBreaks(GBool pageBreaks);
-  GBool setEnableFreeType(char *s);
-  void setOverprintPreview(GBool overprintPreviewA);
-  void setPrintCommands(GBool printCommandsA);
-  void setProfileCommands(GBool profileCommandsA);
-  void setErrQuiet(GBool errQuietA);
+  bool setTextEOL(char *s);
+  void setTextPageBreaks(bool pageBreaks);
+  bool setEnableFreeType(char *s);
+  void setOverprintPreview(bool overprintPreviewA);
+  void setPrintCommands(bool printCommandsA);
+  void setProfileCommands(bool profileCommandsA);
+  void setErrQuiet(bool errQuietA);
 
-  static GBool parseYesNo2(const char *token, GBool *flag);
-
-  //----- security handlers
-
-  void addSecurityHandler(XpdfSecurityHandler *handler);
-  XpdfSecurityHandler *getSecurityHandler(char *name);
+  static bool parseYesNo2(const char *token, bool *flag);
 
 private:
 
-  void parseNameToUnicode(GooString *name);
+  void parseNameToUnicode(const GooString *name);
   UnicodeMap *getUnicodeMap2(GooString *encodingName);
 
   void scanEncodingDirs();
-  void addCIDToUnicode(GooString *collection, GooString *fileName);
-  void addUnicodeMap(GooString *encodingName, GooString *fileName);
-  void addCMapDir(GooString *collection, GooString *dir);
+  void addCIDToUnicode(const GooString *collection, const GooString *fileName);
+  void addUnicodeMap(const GooString *encodingName, const GooString *fileName);
+  void addCMapDir(const GooString *collection, const GooString *dir);
 
   //----- static tables
 
@@ -196,55 +185,48 @@ private:
     nameToUnicodeZapfDingbats;
   NameToCharCode *		// mapping from char name to Unicode for text
     nameToUnicodeText;		// extraction
-  GooHash *cidToUnicodes;		// files for mappings from char collections
-				//   to Unicode, indexed by collection name
-				//   [GooString]
-  GooHash *unicodeToUnicodes;	// files for Unicode-to-Unicode mappings,
-				//   indexed by font name pattern [GooString]
-  GooHash *residentUnicodeMaps;	// mappings from Unicode to char codes,
-				//   indexed by encoding name [UnicodeMap]
-  GooHash *unicodeMaps;		// files for mappings from Unicode to char
-				//   codes, indexed by encoding name [GooString]
-  GooHash *cMapDirs;		// list of CMap dirs, indexed by collection
-				//   name [GooList[GooString]]
+  // files for mappings from char collections
+  // to Unicode, indexed by collection name
+  std::unordered_map<std::string, std::string> cidToUnicodes;
+  // mappings from Unicode to char codes,
+  // indexed by encoding name
+  std::unordered_map<std::string, UnicodeMap> residentUnicodeMaps;
+  // files for mappings from Unicode to char
+  // codes, indexed by encoding name
+  std::unordered_map<std::string, std::string> unicodeMaps;
+  // list of CMap dirs, indexed by collection
+  std::unordered_multimap<std::string, std::string> cMapDirs;
   GooList *toUnicodeDirs;		// list of ToUnicode CMap dirs [GooString]
-  GBool baseFontsInitialized;
+  bool baseFontsInitialized;
 #ifdef _WIN32
-  GooHash *substFiles;	// windows font substitutes (for CID fonts)
+  // windows font substitutes (for CID fonts)
+  std::unordered_map<std::string, std::string> substFiles;
 #endif
-  GooHash *fontFiles;		// font files: font name mapped to path
-				//   [GString]
+  // font files: font name mapped to path
+  std::unordered_map<std::string, std::string> fontFiles;
   SysFontList *sysFonts;	// system fonts
-  GBool psExpandSmaller;	// expand smaller pages to fill paper
-  GBool psShrinkLarger;		// shrink larger pages to fit paper
+  bool psExpandSmaller;	// expand smaller pages to fill paper
+  bool psShrinkLarger;		// shrink larger pages to fit paper
   PSLevel psLevel;		// PostScript level to generate
   GooString *textEncoding;	// encoding (unicodeMap) to use for text
 				//   output
   EndOfLineKind textEOL;	// type of EOL marker to use for text
 				//   output
-  GBool textPageBreaks;		// insert end-of-page markers?
-  GBool enableFreeType;		// FreeType enable flag
-  GBool overprintPreview;	// enable overprint preview
-  GBool printCommands;		// print the drawing commands
-  GBool profileCommands;	// profile the drawing commands
-  GBool errQuiet;		// suppress error messages?
+  bool textPageBreaks;		// insert end-of-page markers?
+  bool enableFreeType;		// FreeType enable flag
+  bool overprintPreview;	// enable overprint preview
+  bool printCommands;		// print the drawing commands
+  bool profileCommands;	// profile the drawing commands
+  bool errQuiet;		// suppress error messages?
 
   CharCodeToUnicodeCache *cidToUnicodeCache;
   CharCodeToUnicodeCache *unicodeToUnicodeCache;
   UnicodeMapCache *unicodeMapCache;
   CMapCache *cMapCache;
   
-#ifdef ENABLE_PLUGINS
-  GooList *plugins;		// list of plugins [Plugin]
-  GooList *securityHandlers;	// list of loaded security handlers
-				//   [XpdfSecurityHandler]
-#endif
-
-#ifdef MULTITHREADED
-  GooMutex mutex;
-  GooMutex unicodeMapCacheMutex;
-  GooMutex cMapCacheMutex;
-#endif
+  mutable std::recursive_mutex mutex;
+  mutable std::recursive_mutex unicodeMapCacheMutex;
+  mutable std::recursive_mutex cMapCacheMutex;
 
   const char *popplerDataDir;
 };
