@@ -16,8 +16,9 @@
 // Copyright (C) 2008 Koji Otani <sho@bbr.jp>
 // Copyright (C) 2012, 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2012 Hib Eris <hib@hiberis.nl>
-// Copyright (C) 2016 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2016, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2016 Jason Crain <jason@aquaticape.us>
+// Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -52,7 +53,7 @@ int UTF16toUCS4(const Unicode *utf16, int utf16Len, Unicode **ucs4)
     }
     len++;
   }
-  if (ucs4 == NULL)
+  if (ucs4 == nullptr)
     return len;
 
   u = (Unicode*)gmallocn(len, sizeof(Unicode));
@@ -85,16 +86,16 @@ int UTF16toUCS4(const Unicode *utf16, int utf16Len, Unicode **ucs4)
   return len;
 }
 
-int TextStringToUCS4(GooString *textStr, Unicode **ucs4)
+int TextStringToUCS4(const GooString *textStr, Unicode **ucs4)
 {
   int i, len;
   const char *s;
   Unicode *u;
 
   len = textStr->getLength();
-  s = textStr->getCString();
+  s = textStr->c_str();
   if (len == 0) {
-    *ucs4 = 0;
+    *ucs4 = nullptr;
     return 0;
   }
 
@@ -109,7 +110,7 @@ int TextStringToUCS4(GooString *textStr, Unicode **ucs4)
       len = UTF16toUCS4(utf16, len, &u);
       delete[] utf16;
     } else {
-      u = NULL;
+      u = nullptr;
     }
   } else {
     u = (Unicode*)gmallocn(len, sizeof(Unicode));
@@ -331,7 +332,7 @@ inline uint32_t decodeUtf16(uint32_t* state, uint32_t* codePoint, uint16_t codeU
 // UTF-8 (excluding terminating NULL).
 int utf16CountUtf8Bytes(const uint16_t *utf16)
 {
-    uint32_t codepoint;
+    uint32_t codepoint = 0;
     uint32_t state = 0;
     int count = 0;
 
