@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2009, 2016 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2009, 2016, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012 Fabio D'Urso <fabiodurso@hotmail.it>
 //
 // To see a description of the changes please see the Changelog file that
@@ -48,7 +48,7 @@ struct SplashScreenPoint {
 
 
 struct cmpDistancesFunctor {
-  bool operator()(const SplashScreenPoint &p0, const SplashScreenPoint &p1) {
+  bool operator()(const SplashScreenPoint p0, const SplashScreenPoint p1) {
     return p0.dist < p1.dist;
   }
 };
