@@ -11,7 +11,7 @@
 // All changes made under the Poppler project to this file are licensed
 // under GPL version 2 or later
 //
-// Copyright (C) 2008, 2010, 2014 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008, 2010, 2014, 2018 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2010 Paweł Wiejacha <pawel.wiejacha@gmail.com>
 // Copyright (C) 2013, 2014 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
@@ -319,7 +319,7 @@ void SplashXPathScanner::computeIntersections() {
   }
   for (auto& line : allIntersections) {
     std::sort(line.begin(), line.end(),
-              [](const SplashIntersect &i0, const SplashIntersect &i1) {
+              [](const SplashIntersect i0, const SplashIntersect i1) {
                 return i0.x0 < i1.x0;
               });
   }
